"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const StorageErrorFactory_1 = tslib_1.__importDefault(require("../errors/StorageErrorFactory"));
const models_1 = require("../generated/artifacts/models");
class BlobWriteLeaseValidator {
    constructor(leaseAccessConditions) {
        this.leaseAccessConditions = leaseAccessConditions;
    }
    validate(lease, context) {
        // check Leased -> Expired
        if (lease.leaseStatus === models_1.LeaseStatusType.Locked) {
            if (this.leaseAccessConditions === undefined ||
                this.leaseAccessConditions.leaseId === undefined ||
                this.leaseAccessConditions.leaseId === "") {
                throw StorageErrorFactory_1.default.getBlobLeaseIdMissing(context.contextId);
            }
            else if (lease.leaseId !== undefined &&
                this.leaseAccessConditions.leaseId.toLowerCase() !==
                    lease.leaseId.toLowerCase()) {
                throw StorageErrorFactory_1.default.getBlobLeaseIdMismatchWithBlobOperation(context.contextId);
            }
        }
        else if (this.leaseAccessConditions !== undefined &&
            this.leaseAccessConditions.leaseId !== undefined &&
            this.leaseAccessConditions.leaseId !== "") {
            throw StorageErrorFactory_1.default.getBlobLeaseLost(context.contextId);
        }
    }
}
exports.default = BlobWriteLeaseValidator;
//# sourceMappingURL=BlobWriteLeaseValidator.js.map