"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * End middleware is used to send out final HTTP response.
 *
 * @export
 * @param {Context} context
 * @param {Request} req An express compatible Request object
 * @param {Response} res An express compatible Response object
 * @param {ILogger} logger A valid logger
 */
function endMiddleware(context, res, logger) {
    const totalTimeInMS = context.startTime
        ? new Date().getTime() - context.startTime.getTime()
        : undefined;
    logger.info(
    // tslint:disable-next-line:max-line-length
    `EndMiddleware: End response. TotalTimeInMS=${totalTimeInMS} StatusCode=${res.getStatusCode()} StatusMessage=${res.getStatusMessage()} Headers=${JSON.stringify(res.getHeaders())}`, context.contextID);
    res.getBodyStream().end();
}
exports.default = endMiddleware;
//# sourceMappingURL=end.middleware.js.map