"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const StorageErrorFactory_1 = tslib_1.__importDefault(require("../errors/StorageErrorFactory"));
const LokiJsQueryTranscriberFactory_1 = tslib_1.__importDefault(require("./QueryTranscriber/LokiJsQueryTranscriberFactory"));
/**
 * Handles Query Logic For LokiJs Table Implementation
 *
 * @export
 * @class LokiTableStoreQueryGenerator
 */
class LokiTableStoreQueryGenerator {
    /**
     * Will throw an exception on invalid query syntax
     *
     * @param queryOptions
     * @param context
     * @returns (entity: Entity) => boolean
     */
    static generateQueryForPersistenceLayer(queryOptions, context) {
        let queryWhere;
        try {
            queryWhere =
                LokiTableStoreQueryGenerator.generateQueryEntityWhereFunction(queryOptions.filter);
        }
        catch (e) {
            throw StorageErrorFactory_1.default.getQueryConditionInvalid(context);
        }
        return queryWhere;
    }
    /**
     * Generates the table query function
     *
     * @static
     * @param {(string | undefined)} query
     * @return {*}  {(entity: Table) => boolean}
     * @memberof LokiTableStoreQueryGenerator
     */
    static generateQueryTableWhereFunction(query) {
        if (query === undefined) {
            return () => true;
        }
        const transformedQuery = LokiTableStoreQueryGenerator.transformTableQuery(query);
        return new Function("item", transformedQuery);
    }
    /**
     * generates a table query for the Loki Js table store
     *
     * @static
     * @param {string} query
     * @return {*}  {string}
     * @memberof LokiTableStoreQueryGenerator
     */
    static transformTableQuery(query) {
        const queryTranscriber = LokiJsQueryTranscriberFactory_1.default.createTableQueryTranscriber(query, "lokiJsTableQueryTranscriber");
        queryTranscriber.transcribe();
        return queryTranscriber.getTranscribedQuery();
    }
    /**
     * generates an entity query for the Loki Js table store
     *
     * @static
     * @param {(string | undefined)} query
     * @return {*}  {(entity: Entity) => boolean}
     * @memberof LokiTableStoreQueryGenerator
     */
    static generateQueryEntityWhereFunction(query) {
        if (query === undefined) {
            return () => true;
        }
        const queryTranscriber = LokiJsQueryTranscriberFactory_1.default.createEntityQueryTranscriber(query, "lokiJsQueryTranscriber");
        queryTranscriber.transcribe();
        return new Function("item", queryTranscriber.getTranscribedQuery());
    }
}
exports.default = LokiTableStoreQueryGenerator;
//# sourceMappingURL=LokiTableStoreQueryGenerator.js.map